@@ -45,7 +45,7 @@ if [ "$1" == 'readESSIDinfo' ]; then
     cat $2/wlanInfo-01.csv | grep -e "$3" | grep -e WPA -e WEP | awk -F "," 'BEGIN {OFS = "\n"}; {print $14,$1,$4,$6}'; 
 fi 
 
-if  [ "$1" == 'deleteCaptured' ]; then 
+if [ "$1" == 'deleteCaptured' ]; then 
     ls -al $2/capturedData/$3/"$4"*.*; 
     rm $2/capturedData/$3/"$4"*.*; 
 fi 
@@ -55,8 +55,14 @@ if [ "$1" == 'capture' ]; then
     airodump-ng --channel $2 --bssid $3 --write $4/capturedData/$5/$6 wlan0
 fi 
 
-if  [ "$1" == 'authenticate' ]; then 
-    aireplay-ng -1 5 -q 10 -e $2 -a $3 -h $4 wlan0
+if [ "$1" == 'authenticate' ]; then
+    if    [ "$#" == '4' ]; then
+        aireplay-ng -1 5 -q 10 -a $2 -h $3 -e $4 wlan0
+    elif  [ "$#" == '5' ]; then
+        aireplay-ng -1 5 -q 10 -a $2 -h $3 -e "$4 $5" wlan0
+    elif  [ "$#" == '6' ]; then
+        aireplay-ng -1 5 -q 10 -a $2 -h $3 -e "$4 $5 $6" wlan0
+    fi   
 fi 
 
 if [ "$1" == 'deauthenticate' ]; then 
