@@ -11,7 +11,7 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 
-Version = '1.9'
+Version = '1.10'
 Build = '1'
 
 import sys
@@ -249,7 +249,7 @@ class clevenMainWindow(QtGui.QMainWindow): # need fixes
        '''Opens an xterm window that sends authentication packets.'''
        
        # print "authenticate options: ", essid, bssid, myMAC
-       os.system('osso-xterm -e "sudo %s/%s authenticate %s %s %s" &' % (pathMain, helperScript, essid, bssid, myMAC))
+       os.system('osso-xterm -e "sudo %s/%s authenticate %s %s %s" &' % (pathMain, helperScript, bssid, myMAC, essid))
 
     def executeInjection(self):
        '''Opens an xterm window that sends injection packets.'''
@@ -466,8 +466,7 @@ class clevenSelectDictionary(QtGui.QDialog): # Complete
 
        self.close()
 
- 
-class clevenDecryptCaptured(QtGui.QMainWindow): # on change
+class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
 
     def __init__(self, parent=None):
        ##Build the parent user interface
